==> opensaml-soap-impl-4.1.1-sources.jar: org/opensaml/soap/wsaddressing/impl/AttributedUnsignedLongMarshaller.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wsaddressing.impl;

import net.shibboleth.utilities.java.support.xml.ElementSupport;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.MarshallingException;
import org.opensaml.core.xml.util.XMLObjectSupport;
import org.opensaml.soap.wsaddressing.AttributedUnsignedLong;
import org.w3c.dom.Element;

/**
 * Marshaller for instances of {@link AttributedUnsignedLong}.
 */
public class AttributedUnsignedLongMarshaller extends AbstractWSAddressingObjectMarshaller {

    /** {@inheritDoc} */
    protected void marshallAttributes(final XMLObject xmlObject, final Element domElement) throws MarshallingException {
        final AttributedUnsignedLong aul = (AttributedUnsignedLong) xmlObject;
        XMLObjectSupport.marshallAttributeMap(aul.getUnknownAttributes(), domElement);
    }

    /** {@inheritDoc} */
    protected void marshallElementContent(final XMLObject xmlObject, final Element domElement)
            throws MarshallingException {
        final AttributedUnsignedLong aul = (AttributedUnsignedLong) xmlObject;
        if (aul.getValue() != null) {
            ElementSupport.appendTextContent(domElement, aul.getValue().toString());
        }
    }

}

==> opensaml-soap-impl-5.1.3-sources.jar: org/opensaml/soap/wsaddressing/impl/AttributedUnsignedLongMarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wsaddressing.impl;

import javax.annotation.Nonnull;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.MarshallingException;
import org.opensaml.core.xml.util.XMLObjectSupport;
import org.opensaml.soap.wsaddressing.AttributedUnsignedLong;
import org.w3c.dom.Element;

import net.shibboleth.shared.xml.ElementSupport;

/**
 * Marshaller for instances of {@link AttributedUnsignedLong}.
 */
public class AttributedUnsignedLongMarshaller extends AbstractWSAddressingObjectMarshaller {

    /** {@inheritDoc} */
    protected void marshallAttributes(@Nonnull final XMLObject xmlObject, @Nonnull final Element domElement)
            throws MarshallingException {
        final AttributedUnsignedLong aul = (AttributedUnsignedLong) xmlObject;
        XMLObjectSupport.marshallAttributeMap(aul.getUnknownAttributes(), domElement);
    }

    /** {@inheritDoc} */
    protected void marshallElementContent(@Nonnull final XMLObject xmlObject, @Nonnull final Element domElement)
            throws MarshallingException {
        final AttributedUnsignedLong aul = (AttributedUnsignedLong) xmlObject;
        final Long val = aul.getValue();
        if (val != null) {
            ElementSupport.appendTextContent(domElement, val.toString());
        }
    }

}
